@@ -3,10 +3,10 @@ import multiprocessing
 import sys
 from time import time
 import pdf2image
-import pytesseract
 import numpy as np
-from .engine import get_instruments_dict, cropImage, predictParts, predict_parts, parse_pytesseract_data
+from .engine import get_instruments_dict, predict_parts, TesserocrDetections
 from PyPDF2 import PdfFileReader
+from tesserocr import PyTessBaseAPI, RIL, iterate_level, PSM, OEM
 
 
 class SimpleTimer:
@@ -27,7 +27,6 @@ class PdfPredictor():
         use_lstm=False,
         tessdata_dir=None,
         log_stream=sys.stdout,
-        use_multiprocessing=False,
         crop_to_top=False,
         crop_to_left=True,
         ):
@@ -42,7 +41,6 @@ class PdfPredictor():
         self.use_lstm = use_lstm
         self.tessdata_dir = tessdata_dir
         self.log_stream = log_stream
-        self.use_multiprocessing = use_multiprocessing
         self.crop_to_top = crop_to_top
         self.crop_to_left = crop_to_left
         self.crop = crop_to_top or crop_to_left
@@ -67,47 +65,40 @@ class PdfPredictor():
                     img = img.crop((0, 0, img.width, img.height//2))
                 if self.crop_to_left:
                     img = img.crop((0, 0, img.width//2, img.height))
-            img = np.array(img)
             self.log("detecting...")
-            config = "--user-words sheetmusicUploader/instrumentsToLookFor.txt --psm 11 --dpi 200 -l eng"
-            if self.use_lstm: config += " --oem 1"
-            if self.tessdata_dir != None: config += " --tessdata-dir \""+self.tessdata_dir+"\""
-            pytesseract_args = [img]
-            pytesseract_kwargs = {
-                "output_type": pytesseract.Output.DICT,
-                "config": config,
+            timer = SimpleTimer()
+            tesserocr_kwargs = {
+                "psm": PSM.SPARSE_TEXT,
             }
-            timer = SimpleTimer()
-            if self.use_multiprocessing:
-                detection_data = multiprocessing.Pool().apply(
-                    pytesseract.image_to_data,
-                    pytesseract_args,
-                    pytesseract_kwargs,
-                )
-            else:
-                detection_data = pytesseract.image_to_data(*pytesseract_args, **pytesseract_kwargs)
-            self.log(f"done in {timer} seconds")
-            self.log("predicting...")
-            timer = SimpleTimer()
-            detections = parse_pytesseract_data(detection_data)
-            parts = list(predict_parts(detections, self.instruments))
-            self.log(f"done in {timer} seconds")
-            self.log("parts:", [part for part in parts])
-            for j, (name, part_number, instruments) in enumerate(parts):
-                if lastPartName == name:
-                    continue
-                if lastPartName:
-                    yield {
-                        "name": lastPartName,
-                        "partNumber": lastPartNumber,
-                        "instruments": lastInstruments,
-                        "fromPage": lastPartNamePage,
-                        "toPage": i if j == 0 else i+1
-                    }
-                lastPartName = name
-                lastPartNumber = part_number
-                lastPartNamePage = i+1
-                lastInstruments = instruments
+            if self.use_lstm:
+                tesserocr_kwargs["oem"] = OEM.LSTM_ONLY
+            if self.tessdata_dir != None:
+                tesserocr_kwargs["path"] = self.tessdata_dir
+            with PyTessBaseAPI(**tesserocr_kwargs) as api:
+                api.SetImage(img)
+                api.Recognize()
+                self.log(f"done in {timer} seconds")
+                self.log("predicting...")
+                timer = SimpleTimer()
+                detections = TesserocrDetections(api)
+                parts = list(predict_parts(detections, self.instruments))
+                self.log(f"done in {timer} seconds")
+                self.log("parts:", [part for part in parts])
+                for j, (name, part_number, instruments) in enumerate(parts):
+                    if lastPartName == name:
+                        continue
+                    if lastPartName:
+                        yield {
+                            "name": lastPartName,
+                            "partNumber": lastPartNumber,
+                            "instruments": lastInstruments,
+                            "fromPage": lastPartNamePage,
+                            "toPage": i if j == 0 else i+1
+                        }
+                    lastPartName = name
+                    lastPartNumber = part_number
+                    lastPartNamePage = i+1
+                    lastInstruments = instruments
         if lastPartName:
             yield {
                 "name": lastPartName,
@@ -116,4 +107,3 @@ class PdfPredictor():
                 "fromPage": lastPartNamePage,
                 "toPage": pdfReader.getNumPages()
             }
-
